<?php
/**
 * 404 Monitor Module
 * 
 * @version 1.0
 * @since 0.4
 */

if (class_exists('SU_Module')) {

class SU_404s extends SU_Module {
	
	var $hitset;
	
	function init() {
		$this->hitset = new SU_HitSet($this->get_module_key(), "status_code=404 AND redirect_url=''");
	}
	
	function get_menu_title() { return __('404 Monitor', 'seo-ultimate'); }
	/*function get_menu_count() {
		global $wpdb;
		$table = SEO_Ultimate::get_table_name('hits');
		return $wpdb->query("SELECT id FROM $table WHERE status_code=404 AND is_new=1");
	}
	function get_menu_count_label() { return __('New 404 Errors', 'seo-ultimate'); }*/
	
	function admin_page_contents() {
		
		global $wpdb;
		$table = SEO_Ultimate::get_table_name('hits');
		
		if ($this->is_action('delete')) {
			
			if ($wpdb->query($wpdb->prepare("DELETE FROM $table WHERE id = %d LIMIT 1", $_GET['object'])))
				$this->queue_message('success', __('The log entry was successfully deleted.', 'seo-ultimate'));
			else
				$this->queue_message('error', __('This log entry has already been deleted.', 'seo-ultimate'));
			
			$this->hitset->query_db();
			
		} elseif ($this->is_action('clear')) {
			
			if ($wpdb->query("DELETE FROM $table WHERE status_code=404")) {
				$this->queue_message('success', __('The log was successfully cleared.', 'seo-ultimate'));
				$this->hitset->query_db();
			}
		}
		
		if (!$this->hitset->have_hits())
			$this->queue_message('success', __("No 404 errors in the log.", 'seo-ultimate'));
				
		$this->print_messages();
		
		if ($this->hitset->have_hits()) {
			
			$this->hitset->admin_table(array($this, 'hits_table_action_links'));
			
			$clearurl = $this->get_nonce_url('clear');
			$confirm = __("Are you sure you want to delete all 404 log entries?", 'seo-ultimate');
			echo "<a href=\"$clearurl\" class=\"button-secondary\" onclick=\"javascript:return confirm('$confirm')\">";
			_e("Clear Log", 'seo-ultimate');
			echo "</a>";
		}
	}
	
	function hits_table_action_links($row) {
		$url = $row['url'];
		
		$deleteurl = $this->get_nonce_url('delete', $row['id']);
		$url_encoded = urlencode($url);
		
		$anchors = array(
			  __("Open", 'seo-ultimate')
			, __("Google Cache", 'seo-ultimate')
			, __("Delete Log Entry", 'seo-ultimate')
		);
		
		return <<<STR

				<span class="open"><a href="$url" target="_blank">{$anchors[0]}</a> | </span>
				<span class="cache"><a href="http://www.google.com/search?q=cache%3A$url_encoded" target="_blank">{$anchors[1]}</a> | </span>
				<span class="delete"><a href="$deleteurl">{$anchors[2]}</a></span>

STR;
	}
	
	function admin_help() {
		
		if ($this->hitset->have_hits()) {
			
			return __(<<<STR
<p>The 404 Monitor keeps track of non-existant URLs that generated 404 errors. 404 errors are when a search engine or visitor comes to a URL on your site but nothing exists at that URL. 
The 404 Monitor helps you spot 404 errors; then you can take steps to correct them (e.g. finding the broken links responsible or creating redirects).</p>
<p>Hover over a table row to access these options:</p>
<ul>
	<li>The &#8220;View&#8221; link will open the URL in a new window. This is useful for testing whether or not a redirect is working.</li>
	<li>The &#8220;Google Cache&#8221; link will open Google&#8217;s archived version of the URL in a new window. This is useful for determining what content, if any, used to be located at that URL.</li>
	<li>Once you've taken care of a 404 error, you can click the &#8220;Delete Log Entry&#8221; link to remove it from the list. The URL will reappear on the list if it triggers a 404 error in the future.</li>
</ul>
<p>If there are any newly-logged URLs that you haven&#8217;t seen yet, these new URLs will be highlighted green in the table.</p>
<p>Notes:</p>
<ul>
	<li>In order for the 404 Monitor to track 404 errors, you must have &#8220;Pretty Permalinks&#8221; enabled in your <a href="options-permalink.php">permalink options</a>.</li>
	<li>Some parts of your website may not be under WordPress&#8217;s control; the 404 Monitor can&#8217;t track 404 errors on non-WordPress website areas.</li>
	<li>The 404 Monitor doesn&#8217;t record 404 errors generated by logged-in users.</li>
</ul>
STR
, 'seo-ultimate');

/*<p>A numeric bubble will appear next to the &#8220;404 Monitor&#8221; item on the menu if there are any newly-logged URLs that you haven&#8217;t seen yet. 
These new URLs will also be highlighted green in the table.</p>*/

		} else {
		
			return __(<<<STR
<p>Currently, the 404 Monitor doesn&#8217;t have any 404 errors in its log. This is good, and means there&#8217;s no action required on your part. 
If the 404 Monitor logs any 404 errors in the future, you&#8217;ll see them on this page.</p>
<p>Notes:</p>
<ul>
	<li>In order for the 404 Monitor to track 404 errors, you must have &#8220;Pretty Permalinks&#8221; enabled in your <a href="options-permalink.php">permalink options</a>.</li>
	<li>Some parts of your website may not be under WordPress&#8217;s control; the 404 Monitor can&#8217;t track 404 errors on non-WordPress website areas.</li>
	<li>The 404 Monitor doesn&#8217;t record 404 errors generated by logged-in users.</li>
</ul>
STR
, 'seo-ultimate');
		}
	}
}

}
?>